@@ -3,24 +3,29 @@ import json
 from oneparams.api.base_diff import BaseDiff
 from oneparams.api.perfils import Perfil
 from oneparams.api.profissao import Profissao
+from oneparams.utils import create_cel, create_email
 
 
 class Colaboradores(BaseDiff):
     items = []
+    list_details = []
     first_get = False
 
     def __init__(self):
         super().__init__(
             key_id="colaboradorId",
             key_name="nomeCompleto",
+            key_active="ativoColaborador",
             item_name="collaborator",
             url_create="/OCliForColsUsuarioPerfil/CreateColaboradores",
             url_update="/OCliForColsFiliais/UpdateColaboradores",
             url_get_all="/CliForCols/ListaDetalhesColaboradores",
-            url_get_detail="/OColaborador/DetalhesColaboradores")
+            url_get_detail="/OColaborador/DetalhesColaboradores",
+            submodules={
+                "profissao": Profissao(),
+                "perfil": Perfil()
+            })
 
-        self.profissao = Profissao()
-        self.perfil = Perfil()
         if not Colaboradores.first_get:
             self.get_all()
             Colaboradores.first_get = True
@@ -43,36 +48,30 @@ class Colaboradores(BaseDiff):
     def details(self, item_id):
         return super().details(item_id)["colaboradoresCliForColsLightModel"]
 
+    def equals(self, data):
+        if data["email"] is None:
+            data.pop("email")
+        if data["celular"] is None:
+            data.pop("celular")
+        return super().equals(data)
+
+    def create(self, data):
+        if data["email"] is None:
+            data["email"] = create_email()
+        if data["celular"] is None:
+            data["celular"] = create_cel()
+        super().create(data)
+
+    def update(self, data):
+        if "email" not in data.keys():
+            data["email"] = self.details(data[self.key_id])["email"]
+        if "celular" not in data.keys():
+            data["celular"] = self.details(data[self.key_id])["celular"]
+        return super().update(data)
+
     def item_id(self, data):
         for i in self.items:
             if (i[self.key_name] == data[self.key_name]
                     or i["email"] == data["email"]):
                 return i[self.key_id]
         return 0
-
-    def name_to_id(self, data):
-        erros = []
-        if "profissao" in data.keys():
-            try:
-                data["profissaoId"] = self.profissao.profissao_id(
-                    data["profissao"])
-            except ValueError as exp:
-                erros.append(str(exp))
-            data.pop("profissao")
-
-        if "perfil" in data.keys():
-            try:
-                data["perfilId"] = self.perfil.perfil_id(data["perfil"])
-            except ValueError as exp:
-                erros.append(str(exp))
-            data.pop("perfil")
-
-        if erros != []:
-            raise Exception(erros)
-
-        data["ativoColaborador"] = True
-        return data
-
-    def colaborador(self, data):
-        data = self.name_to_id(data)
-        super().diff_item(data)
