@@ -1,5 +1,3 @@
-import sys
-
 from oneparams.api.app import App
 from oneparams.api.colaborador import Colaboradores
 from oneparams.excel.excel import Excel
@@ -45,8 +43,12 @@ def colaborador(book, app_regist=False):
     data = ex.data_all(check_row=checks)
     for row in data:
 
-        one.colaborador(row)
-        if app_regist:
+        email_exist = True
+        if row["email"] is None or row["celular"] is None:
+            email_exist = False
+
+        one.diff_item(row)
+        if app_regist and email_exist:
             app.app(nome=row["nomeCompleto"],
                     email=row["email"],
                     celular=row["celular"])
@@ -58,38 +60,59 @@ def checks(row, data, previous):
     try:
         data["celular"] = get_cel(data["celular"])
     except ValueError as exp:
-        print("ERROR! in line {}: {}".format(row + 1, exp))
-        erros = True
+        if data["celular"] is None:
+            print(
+                f'WARNING! on line {row + 1}: Collaborator {data["nomeCompleto"]} has empty phone'
+            )
+        else:
+            print(
+                f'ERROR! in line {row + 1}: Collaborator {data["nomeCompleto"]} has {exp}'
+            )
+            erros = True
 
     if data["nomeCompleto"] is None:
-        print("ERROR! in line {}: empty name".format(row + 1))
+        print("ERROR! in line {row + 1}: empty name")
         erros = True
-    if data["email"] is None:
-        print("ERROR! in line {}: empty email".format(row + 1))
+    if len(data["nomeCompleto"]) > 50:
+        print(
+            f'ERROR! in line {row + 1}: Collaborator {data["nomeCompleto"]} name size {len(data["nomeCompleto"])} > 50'
+        )
         erros = True
 
+    try:
+        if len(data["email"]) > 150:
+            print(
+                f'ERROR! in line {row + 1}: Collaborator email {data["email"]} size {len(data["email"])} > 150'
+            )
+            erros = True
+    except TypeError:
+        print(
+            f'WARNING! in line {row + 1}: Collaborator {data["nomeCompleto"]} email is empty'
+        )
+
     for prev in previous:
         nome = deemphasize(data["nomeCompleto"])
         prev_nome = deemphasize(prev["data"]["nomeCompleto"])
         if nome == prev_nome:
             print(
-                "ERROR! in lines {} and {}: collaborator's name is duplicated".
-                format(row + 1, prev["row"] + 1))
+                f'ERROR! in lines {row + 1} and {prev["row"] + 1}: collaborator\'s {data["nomeCompleto"]} name is duplicated'
+            )
             erros = True
 
-        email = deemphasize(data["email"])
-        prev_email = deemphasize(prev["data"]["email"])
-        if email == prev_email:
-            print(
-                "ERROR! in lines {} and {}: collaborator's email is duplicated"
-                .format(row + 1, prev["row"] + 1))
-            erros = True
+        if data["email"] is not None:
+            email = deemphasize(data["email"])
+            prev_email = deemphasize(prev["data"]["email"])
+            if email == prev_email:
+                print(
+                    f'ERROR! in lines {row + 1} and {prev["row"] + 1}: collaborator\'s email {data["email"]} is duplicated'
+                )
+                erros = True
 
     one = Colaboradores()
     try:
         data = one.name_to_id(data)
     except Exception as exp:
-        print("ERROR! in line {}: {}".format(row + 1, exp))
+        print(f'ERROR! in line {row + 1}: {exp}')
         erros = True
 
     if erros:
